Class: HeedKit::Configuration
- Inherits:
-
Object
- Object
- HeedKit::Configuration
- Defined in:
- lib/heedkit.rb
Instance Attribute Summary collapse
-
#endpoint ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash).
-
#project_key ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash).
-
#secret_key ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash).
-
#timeout ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash).
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
27 28 29 30 |
# File 'lib/heedkit.rb', line 27 def initialize @endpoint = "https://api.heedkit.com" @timeout = 5 end |
Instance Attribute Details
#endpoint ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash). Keep it out of anything that reaches a browser or app binary.
25 26 27 |
# File 'lib/heedkit.rb', line 25 def endpoint @endpoint end |
#project_key ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash). Keep it out of anything that reaches a browser or app binary.
25 26 27 |
# File 'lib/heedkit.rb', line 25 def project_key @project_key end |
#secret_key ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash). Keep it out of anything that reaches a browser or app binary.
25 26 27 |
# File 'lib/heedkit.rb', line 25 def secret_key @secret_key end |
#timeout ⇒ Object
secret_key is the project's SERVER secret (fk_secret_…) — set it so Client#identify can sign external ids (user_hash). Keep it out of anything that reaches a browser or app binary.
25 26 27 |
# File 'lib/heedkit.rb', line 25 def timeout @timeout end |